@@ -3,7 +3,8 @@ package MooseX::WithCache;
 use 5.008;
 use constant DEBUG => $ENV{MOOSEX_WITHCACHE_DEBUG} ? 1 : 0;
 use MooseX::Role::Parameterized;
-our $VERSION   = '0.01002';
+use Class::Load qw/load_class/;
+our $VERSION   = '0.01005';
 our $AUTHORITY = 'cpan:DMAKI';
 my %BACKENDS;
 
@@ -48,7 +49,7 @@ role {
     if ($backend_class !~ s/^\+//) {
         $backend_class = "MooseX::WithCache::Backend::$backend_class";
     }
-    Class::MOP::load_class($backend_class);
+    load_class($backend_class);
     my $backend = $BACKENDS{ $backend_class };
     if (! $backend ) {
         $backend = $backend_class->new();
@@ -109,7 +110,7 @@ MooseX::WithCache - Easy Cache Access From Moose Objects
         my $self = shift;
         my $foo = $self->cache_get( 'foo' );
         if ($foo) {
-            $foo = $self->get_froo_from_database();
+            $foo = $self->get_foo_from_database();
             $self->cache_set(foo => $foo);
         }
         return $foo;
@@ -198,4 +199,4 @@ under the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
 
-=cut
\ No newline at end of file
+=cut
